@@ -17,8 +17,11 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
+import gettext
 from ConfigParser import ConfigParser
 
+gettext.install("debomatic")
+
 class Semaphores:
     pass
 
