@@ -21,7 +21,6 @@ import os
 import sys
 import threading
 from re import findall
-from string import lower
 from Debomatic import gpg
 from Debomatic import locks
 from Debomatic import packages
@@ -39,24 +38,30 @@ def build_process():
         try:
             fd = os.open(os.path.join(directory, package), os.O_RDONLY)
         except:
-            print 'Unable to open %s' % os.path.join(directory, package)
+            print _('Unable to open %s') % os.path.join(directory, package)
             packages.del_package(package)
             sys.exit(-1)
         try:
             for entry in findall('\s\w{32}\s\d+\s\S+\s\S+\s(.*)', os.read(fd, os.fstat(fd).st_size)):
                 packagequeue[package].append(os.path.join(directory, entry))
         except:
-            print 'Bad .changes file'
+            print _('Bad .changes file: %s') % os.path.join(directory, package)
             sys.exit(-1)
         packagequeue[package].append(os.path.join(directory, package))
         os.close(fd)
-        if gpg.check_signature(os.path.join(directory, package)) == False:
+        try:
+            gpg.check_changes_signature(os.path.join(directory, package))
+        except RuntimeError, error:
             packages.rm_package(package)
+            print error
             sys.exit(-1)
 	packages.fetch_missing_files(package, packagequeue[package], directory, distopts)
         distdir = os.path.join(directory, distopts['distribution'])
-        if pbuilder.setup_pbuilder(distdir, configdir, distopts) == False:
+        try:
+            pbuilder.setup_pbuilder(distdir, configdir, distopts)
+        except RuntimeError, error:
             packages.del_package(package)
+            print error
             sys.exit(-1)
         build_package(directory, os.path.join(configdir, distopts['distribution']), distdir, package, distopts)
 
@@ -70,40 +75,40 @@ def parse_distribution_options(packagedir, configdir, package):
         sys.exit(-1)
     try:
         distro = findall('Distribution:\s+(\w+)', os.read(fd, os.fstat(fd).st_size))[0]
-        options['distribution'] = lower(distro)
+        options['distribution'] = distro.lower()
     except:
-        print 'Bad .changes file'
+        print _('Bad .changes file: %s') % os.path.join(packagedir, package)
         packages.del_package(package)
         sys.exit(-1)
     os.close(fd)
     try:
         fd = os.open(os.path.join(configdir,options['distribution']), os.O_RDONLY)
     except:
-        print 'Unable to open %s' % os.path.join(configdir, options['distribution'])
+        print _('Unable to open %s') % os.path.join(configdir, options['distribution'])
         packages.del_package(package)
         sys.exit(-1)
     conf = os.read(fd, os.fstat(fd).st_size)
     os.close(fd)
     if not len(findall('[^#]?MIRRORSITE="?(.*[^"])"?\n', conf)):
-        print 'Please set DISTRIBUTION in %s' % os.path.join(configdir, options['distribution'])
+        print _('Please set DISTRIBUTION in %s') % os.path.join(configdir, options['distribution'])
         packages.del_package(package)
         sys.exit(-1)
     try:
         options['mirror'] = findall('[^#]?MIRRORSITE="?(.*[^"])"?\n', conf)[0]
     except:
-        print 'Please set MIRRORSITE in %s' % os.path.join(configdir, options['distribution'])
+        print _('Please set MIRRORSITE in %s') % os.path.join(configdir, options['distribution'])
         packages.del_package(package)
         sys.exit(-1)
     try:
         options['components'] = findall('[^#]?COMPONENTS="?(.*[^"])"?\n', conf)[0]
     except:
-        print 'Please set COMPONENTS in %s' % os.path.join(configdir, options['distribution'])
+        print _('Please set COMPONENTS in %s') % os.path.join(configdir, options['distribution'])
         packages.del_package(package)
         sys.exit(-1)
     try:
         options['debootstrap'] = findall('[^#]?DEBOOTSTRAP="?(.*[^"])"?\n', conf)[0]
     except:
-        print 'Please set DEBOOTSTRAP in %s' % os.path.join(configdir, options['distribution'])
+        print _('Please set DEBOOTSTRAP in %s') % os.path.join(configdir, options['distribution'])
         packages.del_package(package)
         sys.exit(-1)
     return options
@@ -127,11 +132,13 @@ def build_package(directory, configfile, distdir, package, distopts):
         os.mkdir(os.path.join(distdir, 'pool', packageversion))
     mod_sys.execute_hook('pre_build', { 'directory': distdir, 'package': packageversion, \
               'cfg': configfile, 'distribution': distopts['distribution'], 'dsc': dscfile[0]})
-    os.system('pbuilder build --basetgz %(directory)s/%(distribution)s \
+    base = '--basepath' if Options.get('default', 'builder') == 'cowbuilder' else '--basetgz'
+    os.system('%(builder)s --build %(basetype)s %(directory)s/%(distribution)s \
               --override-config --configfile %(cfg)s --logfile %(directory)s/pool/%(package)s/%(package)s.buildlog \
               --buildplace %(directory)s/build --buildresult %(directory)s/pool/%(package)s \
-              --aptcache %(directory)s/aptcache %(dsc)s >/dev/null 2>&1' % { 'directory': distdir, 'package': packageversion, \
-              'cfg': configfile, 'distribution': distopts['distribution'], 'dsc': dscfile[0]})
+              --aptcache %(directory)s/aptcache %(dsc)s >/dev/null 2>&1' \
+              % { 'builder': Options.get('default', 'builder'), 'basetype': base, 'directory': distdir, \
+              'package': packageversion, 'cfg': configfile, 'distribution': distopts['distribution'], 'dsc': dscfile[0]})
     mod_sys.execute_hook('post_build', { 'directory': distdir, 'package': packageversion, \
               'cfg': configfile, 'distribution': distopts['distribution'], 'dsc': dscfile[0]})
     packages.rm_package(package)
