@@ -22,8 +22,10 @@ import sys
 import threading
 from fcntl import lockf, LOCK_EX, LOCK_NB
 from getopt import getopt, GetoptError
+from signal import pause
 from time import sleep
 from Debomatic import build
+from Debomatic import commands
 from Debomatic import Options
 from Debomatic import modules
 from Debomatic import running
@@ -32,7 +34,7 @@ def main():
     conffile = None
     daemon = True
     if os.getuid():
-        print 'You must run deb-o-matic as root'
+        print _('You must run deb-o-matic as root')
         sys.exit(-1)
     try:
         opts, args = getopt(sys.argv[1:], 'c:n', ['config=', 'nodaemon'])
@@ -53,7 +55,7 @@ def main():
             if pid > 0:
                 sys.exit(0)
         except OSError:
-            print 'Fork failed'
+            print _('Unable to enter daemon mode')
             sys.exit(-1)
         os.setsid()
         os.chdir('/')
@@ -63,7 +65,7 @@ def main():
             if pid > 0:
                 sys.exit(0)
         except OSError:
-            print 'Fork failed'
+            print _('Unable to enter daemon mode')
             sys.exit(-1)
         fin = open('/dev/null', 'r')
         fout = open(Options.get('default', 'logfile'), 'a+')
@@ -76,24 +78,24 @@ def main():
     try:
         lockf(fd, LOCK_EX | LOCK_NB)
     except IOError:
-        print 'Another instance is running. Aborting.'
+        print _('Another instance is running. Aborting')
         sys.exit(-1)
     mod_sys = modules.Module()
     mod_sys.execute_hook("on_start", {})
     launcher()
 
 def parse_default_options(conffile):
-    defaultoptions = ('packagedir', 'configdir', 'maxbuilds', 'inotify', 'sleep', 'logfile')
+    defaultoptions = ('builder', 'packagedir', 'configdir', 'maxbuilds', 'inotify', 'sleep', 'logfile')
     if not conffile:
-        print 'Please specify a configuration file'
+        print _('Please specify a configuration file')
         sys.exit(-1)
     if not os.path.exists(conffile):
-        print 'Configuration file %s does not exist' % conffile
+        print _('Configuration file %s does not exist') % conffile
         sys.exit(-1)
     Options.read(conffile)
     for opt in defaultoptions:
         if not Options.has_option('default', opt) or not Options.get('default', opt):
-            print 'Please set "%s" in %s' % (opt, conffile)
+            print _('Please set "%(opt)s" in %(conffile)s') % {'opt':opt, 'conffile':conffile}
             sys.exit(-1)
 
 try:
@@ -105,6 +107,8 @@ try:
         def process_IN_CLOSE_WRITE(self, event):
             if findall('source.changes$', event.name):
                 threading.Thread(None, build.build_process).start()
+            elif findall('commands$', event.name):
+                threading.Thread(None, commands.process_commands).start()
 
     def launcher_inotify():
         if Options.getint('default', 'inotify'):
@@ -118,6 +122,7 @@ except:
 
 def launcher_timer():
     while exit_routine():
+        threading.Thread(None, commands.process_commands).start()
         threading.Thread(None, build.build_process).start()
         sleep(Options.getint('default', 'sleep'))
 
@@ -125,10 +130,9 @@ def launcher():
     threading.Thread(None, launcher_inotify).start()
     threading.Thread(None, launcher_timer).start()
     try:
-        while exit_routine():
-            pass
+        pause()
     except KeyboardInterrupt:
-        print '\nWaiting for threads to finish, it could take a while...'
+        print _('\nWaiting for threads to finish, it could take a while...')
         exit_routine(exiting=True)
 
 def exit_routine(self=None, exiting=False):
