@@ -23,15 +23,15 @@ from subprocess import Popen, PIPE
 from Debomatic import Options
 from Debomatic import acceptedqueue
 
-def check_signature(package):
+def check_changes_signature(package):
     if Options.getint('gpg', 'gpg'):
         if not Options.has_option('gpg', 'keyring') or not os.path.exists(Options.get('gpg', 'keyring')):
-            return False
+            raise RuntimeError(_('Keyring not found'))
         if not package in acceptedqueue:
-            gpgresult = Popen(['gpg', '--primary-keyring', Options.get('gpg', 'keyring'), '--verify', package], stderr=PIPE).communicate()[1]
+            gpgresult = Popen(['gpg', '--no-default-keyring', '--keyring', Options.get('gpg', 'keyring'), '--verify', package], stderr=PIPE).communicate()[1]
             ID = findall('Good signature from "(.*) <(.*)>"', gpgresult)
             if not len(ID):
-                return False
+                raise RuntimeError(_('No valid signatures found'))
             fd = os.open(package, os.O_RDONLY)
             data = os.read(fd, os.fstat(fd).st_size)
             os.close(fd)
@@ -41,3 +41,18 @@ def check_signature(package):
             if not package in acceptedqueue:
                 acceptedqueue.append(package)
 
+def check_commands_signature(commands):
+    if Options.getint('gpg', 'gpg'):
+        if not Options.has_option('gpg', 'keyring') or not os.path.exists(Options.get('gpg', 'keyring')):
+            raise RuntimeError(_('Keyring not found'))
+        gpgresult = Popen(['gpg', '--no-default-keyring', '--keyring', Options.get('gpg', 'keyring'), '--verify', commands], stderr=PIPE).communicate()[1]
+        ID = findall('Good signature from "(.*) <(.*)>"', gpgresult)
+        if not len(ID):
+            raise RuntimeError(_('No valid signatures found'))
+        fd = os.open(commands, os.O_RDONLY)
+        data = os.read(fd, os.fstat(fd).st_size)
+        os.close(fd)
+        fd = os.open(commands, os.O_WRONLY | os.O_TRUNC)
+        os.write(fd, findall('Hash: \S+\n\n(.*)\n\n\-\-\-\-\-BEGIN PGP SIGNATURE\-\-\-\-\-', data, DOTALL)[0])
+        os.close(fd)
+
