@@ -4,7 +4,7 @@
 # Copyright (C) 2008-2009 Luca Falavigna
 #
 # Authors: David Futcher <bobbo@ubuntu.com>
-#          Luca Falavigna <dktrkranz@ubuntu.com>
+#          Luca Falavigna <dktrkranz@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@ class DebomaticModule_DateStamp:
         self.date_file = ""
         
     def pre_build(self, args):    
-        self.date_file = "%(directory)s/result/%(package)s/%(package)s.datestamp" % args
+        self.date_file = "%(directory)s/pool/%(package)s/%(package)s.datestamp" % args
         fd = os.open(self.date_file, os.O_WRONLY | os.O_CREAT | os.O_TRUNC, stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP | stat.S_IROTH)
         os.write(fd, 'Build started at %s\n' % datetime.now().strftime("%A, %d %B %Y %H:%M"))
         os.close(fd)
